@@ -1,38 +1,38 @@
 package Pinto::Common;
 
-# ABSTRACT: Common libraries for the L<Pinto> suite
+# ABSTRACT: Common modules for the pinto-* utilities
 
 use strict;
 use warnings;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.065_04'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 #------------------------------------------------------------------------------
 1;
 
-__END__
+
 
 =pod
 
 =for :stopwords Jeffrey Ryan Thalhammer Imaginative Software Systems cpan testmatrix url
 annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata
-placeholders metacpan
+placeholders
 
 =head1 NAME
 
-Pinto::Common - Common libraries for the L<Pinto> suite
+Pinto::Common - Common modules for the pinto-* utilities
 
 =head1 VERSION
 
-version 0.065_04
+version 0.013
 
 =head1 DESCRIPTION
 
 This distribution exists to provide modules that are used across
-L<pinto> and L<pintod>.  There are no user-serviceable parts in
-this distribution.
+L<pinto-admin>, L<pinto-server>, and L<pinto-remote>.  There are no
+user-serviceable parts in this distribution.
 
 =head1 SUPPORT
 
@@ -59,6 +59,14 @@ L<http://search.cpan.org/dist/Pinto-Common>
 
 =item *
 
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Pinto-Common>
+
+=item *
+
 CPAN Ratings
 
 The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
@@ -77,7 +85,7 @@ L<http://www.cpantesters.org/distro/P/Pinto-Common>
 
 CPAN Testers Matrix
 
-The CPAN Testers Matrix is a website that provides a visual overview of the test results for a distribution on various Perls/platforms.
+The CPAN Testers Matrix is a website that provides a visual way to determine what Perls/platforms PASSed for a distribution.
 
 L<http://matrix.cpantesters.org/?dist=Pinto-Common>
 
@@ -93,18 +101,20 @@ L<http://deps.cpantesters.org/?module=Pinto::Common>
 
 =head2 Bugs / Feature Requests
 
-L<https://github.com/thaljef/Pinto-Common/issues>
+Please report any bugs or feature requests by email to C<bug-pinto-common at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Pinto-Common>. You will be automatically notified of any
+progress on the request by the system.
 
 =head2 Source Code
 
 
 L<https://github.com/thaljef/Pinto-Common>
 
-  git clone git://github.com/thaljef/Pinto-Common.git
+  git clone https://github.com/thaljef/Pinto-Common
 
 =head1 AUTHOR
 
-Jeffrey Ryan Thalhammer <jeff@stratopan.com>
+Jeffrey Ryan Thalhammer <jeff@imaginative-software.com>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -114,3 +124,8 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+
+__END__
+
+
